@@ -5,7 +5,7 @@ use warnings;
 use XSLoader;
 use Exporter::Lite;
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 XSLoader::load('Kafka::Librd', $VERSION);
 
 our @EXPORT_OK;
@@ -315,7 +315,7 @@ L<https://github.com/edenhill/librdkafka>
 =head1 BUGS
 
 Please report any bugs or feature requests via GitHub bug tracker at
-L<http://github.com/plicease/Kafka-Librd/issues>.
+L<http://github.com/uperl/Kafka-Librd/issues>.
 
 =head1 AUTHOR
 
